#!perl -w
use strict;
use Config;
use Test::More tests => 14;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::Net qw( Int2Ip Ip2Int GetHttpContent SupportedIpVersions localhostName);

sub Main {

    ## no critic qw(ProhibitMagicNumbers)
    ok( Ip2Int('1.1.1.1') == 16843009, 'Ip2Int works' );
    ok( Ip2Int('255.255.255.255') == 4294967295, 'Ip2Int works' );
    ok( Int2Ip(16843009) eq '1.1.1.1', 'Int2Ip works' );
    ok( Int2Ip(4294967295) eq '255.255.255.255', 'Int2Ip works' );
    ok( Ip2Int(Int2Ip(56151532)) == 56151532, 'Int -> Ip -> Int' );
    ok( Int2Ip(Ip2Int('127.0.0.1')) eq '127.0.0.1', 'IP -> Int -> IP' );

    ok( Ip2Int('::1:1:1:1') == 281479271743489, 'IPv6: Ip2Int works' );
    ok( Ip2Int('ffff:ffff:ffff:ffff:ffff:ffff:ffff:ffff') eq '340282366920938463463374607431768211455', 'IPv6: Ip2Int works' );

    # GetHttpContent
    my $RobotsTxt = GetHttpContent('http://localhost/WebRoot/robots.txt');
    ok( $RobotsTxt =~ /User-Agent:/i, 'http get robots.txt');
    my $NotFound = GetHttpContent('http://localhost/WebRoot/robots_invalid.txt');
    ok( !defined($NotFound), 'get invalid URL' );

    # localhostName
    my @IPVersions = SupportedIpVersions();
    ok( scalar @IPVersions, 'scalar SupportedIpVersions' );
    ok( $IPVersions[0] == 4 || $IPVersions[0] == 6, 'SupportedIpVersions[0]' );
    ok( scalar @IPVersions < 2 || $IPVersions[1] == 4 || $IPVersions[1] == 6, 'SupportedIpVersions[1]' );
    my $localhostName = localhostName();
    ok( $localhostName eq 'localhost' || $localhostName eq 'ipv6-localhost', 'localhostName' );
}

RunScript(Sub=>\&Main, Debug=>1);
